@@ -12,6 +12,7 @@
 #include <llvm/IR/IRBuilder.h>
 #include <llvm/IR/Instruction.h>
 #include <llvm/IR/Instructions.h>
+#include <llvm/IR/Module.h>
 #include <llvm/IR/PassManager.h>
 #include <llvm/IR/Type.h>
 #include <llvm/Pass.h>
@@ -349,7 +350,11 @@ public:
                                         // Should handle promoting whatever the constant value is (most likely zeroinitializer)
                                         llvm::ConstantFolder Folder;
                                         auto* signExtConstant
+#if OSL_LLVM_VERSION < 180
                                             = Folder.CreateCast(
+#else
+                                            = Folder.FoldCast(
+#endif
                                                 llvm::Instruction::SExt,
                                                 constant, m_native_mask_type);
 
